import React, { useMemo } from 'react';
import { authenticatorTextUtil } from '@aws-amplify/ui';
import { DefaultContent, DefaultFooter, DefaultTextFormFields, DefaultHeader, } from '../../common';
import { useFieldValues } from '../../hooks';
const COMPONENT_NAME = 'SetupEmail';
const { getBackToSignInText, getConfirmText, getConfirmingText, getSetupEmailText, } = authenticatorTextUtil;
const SetupEmail = ({ fields, handleBlur, handleChange, handleSubmit, isPending, toSignIn, validationErrors, ...rest }) => {
    const { disableFormSubmit: disabled, fields: fieldsWithHandlers, fieldValidationErrors, handleFormSubmit, } = useFieldValues({
        componentName: COMPONENT_NAME,
        fields,
        handleBlur,
        handleChange,
        handleSubmit,
        validationErrors,
    });
    const headerText = getSetupEmailText();
    const primaryButtonText = isPending ? getConfirmingText() : getConfirmText();
    const secondaryButtonText = getBackToSignInText();
    const buttons = useMemo(() => ({
        primary: {
            children: primaryButtonText,
            disabled,
            onPress: handleFormSubmit,
        },
        links: [{ children: secondaryButtonText, onPress: toSignIn }],
    }), [
        disabled,
        handleFormSubmit,
        primaryButtonText,
        secondaryButtonText,
        toSignIn,
    ]);
    return (<DefaultContent {...rest} buttons={buttons} headerText={headerText} fields={fieldsWithHandlers} isPending={isPending} validationErrors={fieldValidationErrors}/>);
};
SetupEmail.Footer = DefaultFooter;
SetupEmail.FormFields = DefaultTextFormFields;
SetupEmail.Header = DefaultHeader;
SetupEmail.displayName = COMPONENT_NAME;
export default SetupEmail;
