import React from 'react';
import { censorContactMethod } from '@aws-amplify/ui';
import { Radio, RadioGroup } from '../../../primitives';
const attributeMap = {
    email: 'Email',
    phone_number: 'Phone Number',
};
const DefaultVerifyUserFormFields = ({ fields = [], fieldContainerStyle, fieldLabelStyle, isPending, style, }) => {
    // set initial value for radio field based on selected bool
    const initialValue = fields.find((field) => !!field.selected)?.name;
    return (<RadioGroup disabled={isPending} style={style} initialValue={initialValue}>
      {fields.map(({ name, value, ...props }) => {
            const attributeType = attributeMap[name];
            return (<Radio {...props} key={value} 
            // value has to be name, because Auth is only interested in the
            // string "email" or "phone_number", not the actual value
            value={name} label={censorContactMethod(attributeType, value)} labelStyle={fieldLabelStyle} style={fieldContainerStyle}/>);
        })}
    </RadioGroup>);
};
DefaultVerifyUserFormFields.displayName = 'FormFields';
export default DefaultVerifyUserFormFields;
