"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ui_1 = require("@aws-amplify/ui");
const common_1 = require("../../common");
const hooks_1 = require("../../hooks");
const COMPONENT_NAME = 'ConfirmResetPassword';
const { getResetYourPasswordText, getSubmitText, getSubmittingText, getResendCodeText, } = ui_1.authenticatorTextUtil;
const ConfirmResetPassword = ({ fields, handleBlur, handleChange, handleSubmit, hasValidationErrors, isPending, resendCode, validationErrors, ...rest }) => {
    const { disableFormSubmit, fields: fieldsWithHandlers, fieldValidationErrors, handleFormSubmit, } = (0, hooks_1.useFieldValues)({
        componentName: COMPONENT_NAME,
        fields,
        handleBlur,
        handleChange,
        handleSubmit,
        validationErrors,
    });
    const disabled = hasValidationErrors || disableFormSubmit;
    const headerText = getResetYourPasswordText();
    const primaryButtonText = isPending ? getSubmittingText() : getSubmitText();
    const secondaryButtonText = getResendCodeText();
    const buttons = (0, react_1.useMemo)(() => ({
        primary: {
            children: primaryButtonText,
            disabled,
            onPress: handleFormSubmit,
        },
        secondary: { children: secondaryButtonText, onPress: resendCode },
    }), [
        disabled,
        handleFormSubmit,
        primaryButtonText,
        resendCode,
        secondaryButtonText,
    ]);
    return (<common_1.DefaultContent {...rest} buttons={buttons} headerText={headerText} fields={fieldsWithHandlers} isPending={isPending} validationErrors={fieldValidationErrors}/>);
};
ConfirmResetPassword.Footer = common_1.DefaultFooter;
ConfirmResetPassword.FormFields = common_1.DefaultTextFormFields;
ConfirmResetPassword.Header = common_1.DefaultHeader;
ConfirmResetPassword.displayName = COMPONENT_NAME;
exports.default = ConfirmResetPassword;
