"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ui_1 = require("@aws-amplify/ui");
const common_1 = require("../../common");
const hooks_1 = require("../../hooks");
const COMPONENT_NAME = 'ConfirmSignUp';
const { getDeliveryMethodText, getDeliveryMessageText, getConfirmingText, getConfirmText, getResendCodeText, } = ui_1.authenticatorTextUtil;
const ConfirmSignUp = ({ codeDeliveryDetails, fields, handleBlur, handleChange, handleSubmit, isPending, resendCode, validationErrors, ...rest }) => {
    const { disableFormSubmit: disabled, fields: fieldsWithHandlers, fieldValidationErrors, handleFormSubmit, } = (0, hooks_1.useFieldValues)({
        componentName: COMPONENT_NAME,
        fields,
        handleBlur,
        handleChange,
        handleSubmit,
        validationErrors,
    });
    const headerText = getDeliveryMethodText(codeDeliveryDetails);
    const bodyText = getDeliveryMessageText(codeDeliveryDetails);
    const primaryButtonText = isPending ? getConfirmingText() : getConfirmText();
    const secondaryButtonText = getResendCodeText();
    const buttons = (0, react_1.useMemo)(() => ({
        primary: {
            children: primaryButtonText,
            disabled,
            onPress: handleFormSubmit,
        },
        secondary: { children: secondaryButtonText, onPress: resendCode },
    }), [
        disabled,
        handleFormSubmit,
        primaryButtonText,
        resendCode,
        secondaryButtonText,
    ]);
    return (<common_1.DefaultContent {...rest} body={bodyText} buttons={buttons} headerText={headerText} fields={fieldsWithHandlers} isPending={isPending} validationErrors={fieldValidationErrors}/>);
};
ConfirmSignUp.FormFields = common_1.DefaultTextFormFields;
ConfirmSignUp.Footer = common_1.DefaultFooter;
ConfirmSignUp.Header = common_1.DefaultHeader;
ConfirmSignUp.displayName = COMPONENT_NAME;
exports.default = ConfirmSignUp;
