"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ui_1 = require("@aws-amplify/ui");
const common_1 = require("../../common");
const hooks_1 = require("../../hooks");
const COMPONENT_NAME = 'ConfirmVerifyUser';
const { getAccountRecoveryInfoText, getSkipText, getSubmitText, getSubmittingText, } = ui_1.authenticatorTextUtil;
const ConfirmVerifyUser = ({ fields, handleBlur, handleChange, handleSubmit, isPending, skipVerification, validationErrors, ...rest }) => {
    const { disableFormSubmit: disabled, fields: fieldsWithHandlers, fieldValidationErrors, handleFormSubmit, } = (0, hooks_1.useFieldValues)({
        componentName: COMPONENT_NAME,
        fields,
        handleBlur,
        handleChange,
        handleSubmit,
        validationErrors,
    });
    const headerText = getAccountRecoveryInfoText();
    const primaryButtonText = isPending ? getSubmittingText() : getSubmitText();
    const secondaryButtonText = getSkipText();
    const buttons = (0, react_1.useMemo)(() => ({
        primary: {
            children: primaryButtonText,
            disabled,
            onPress: handleFormSubmit,
        },
        links: [{ children: secondaryButtonText, onPress: skipVerification }],
    }), [
        disabled,
        handleFormSubmit,
        primaryButtonText,
        skipVerification,
        secondaryButtonText,
    ]);
    return (<common_1.DefaultContent {...rest} buttons={buttons} headerText={headerText} fields={fieldsWithHandlers} isPending={isPending} validationErrors={fieldValidationErrors}/>);
};
ConfirmVerifyUser.Footer = common_1.DefaultFooter;
ConfirmVerifyUser.FormFields = common_1.DefaultTextFormFields;
ConfirmVerifyUser.Header = common_1.DefaultHeader;
ConfirmVerifyUser.displayName = COMPONENT_NAME;
exports.default = ConfirmVerifyUser;
