"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ui_1 = require("@aws-amplify/ui");
const common_1 = require("../../common");
const hooks_1 = require("../../hooks");
const COMPONENT_NAME = 'SetupEmail';
const { getBackToSignInText, getConfirmText, getConfirmingText, getSetupEmailText, } = ui_1.authenticatorTextUtil;
const SetupEmail = ({ fields, handleBlur, handleChange, handleSubmit, isPending, toSignIn, validationErrors, ...rest }) => {
    const { disableFormSubmit: disabled, fields: fieldsWithHandlers, fieldValidationErrors, handleFormSubmit, } = (0, hooks_1.useFieldValues)({
        componentName: COMPONENT_NAME,
        fields,
        handleBlur,
        handleChange,
        handleSubmit,
        validationErrors,
    });
    const headerText = getSetupEmailText();
    const primaryButtonText = isPending ? getConfirmingText() : getConfirmText();
    const secondaryButtonText = getBackToSignInText();
    const buttons = (0, react_1.useMemo)(() => ({
        primary: {
            children: primaryButtonText,
            disabled,
            onPress: handleFormSubmit,
        },
        links: [{ children: secondaryButtonText, onPress: toSignIn }],
    }), [
        disabled,
        handleFormSubmit,
        primaryButtonText,
        secondaryButtonText,
        toSignIn,
    ]);
    return (<common_1.DefaultContent {...rest} buttons={buttons} headerText={headerText} fields={fieldsWithHandlers} isPending={isPending} validationErrors={fieldValidationErrors}/>);
};
SetupEmail.Footer = common_1.DefaultFooter;
SetupEmail.FormFields = common_1.DefaultTextFormFields;
SetupEmail.Header = common_1.DefaultHeader;
SetupEmail.displayName = COMPONENT_NAME;
exports.default = SetupEmail;
