"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ui_1 = require("@aws-amplify/ui");
const common_1 = require("../../common");
const hooks_1 = require("../../hooks");
const COMPONENT_NAME = 'VerifyUser';
const { getSkipText, getVerifyContactText, getVerifyText, getAccountRecoveryInfoText, } = ui_1.authenticatorTextUtil;
const VerifyUser = ({ fields, handleBlur, handleChange, handleSubmit, skipVerification, validationErrors, ...rest }) => {
    const { disableFormSubmit: disabled, fields: fieldsWithHandlers, fieldValidationErrors, handleFormSubmit, } = (0, hooks_1.useFieldValues)({
        componentName: COMPONENT_NAME,
        fields,
        handleBlur,
        handleChange,
        handleSubmit,
        validationErrors,
    });
    const headerText = getVerifyContactText();
    const skipText = getSkipText();
    const verifyText = getVerifyText();
    const bodyText = getAccountRecoveryInfoText();
    const buttons = (0, react_1.useMemo)(() => ({
        primary: { children: verifyText, disabled, onPress: handleFormSubmit },
        links: [{ children: skipText, onPress: skipVerification }],
    }), [disabled, handleFormSubmit, skipText, skipVerification, verifyText]);
    return (<common_1.DefaultContent {...rest} body={bodyText} buttons={buttons} fields={fieldsWithHandlers} headerText={headerText} validationErrors={fieldValidationErrors}/>);
};
VerifyUser.Footer = common_1.DefaultFooter;
VerifyUser.FormFields = common_1.DefaultVerifyUserFormFields;
VerifyUser.Header = common_1.DefaultHeader;
VerifyUser.displayName = COMPONENT_NAME;
exports.default = VerifyUser;
