"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_native_1 = require("react-native");
const Icon_1 = require("../Icon");
const Label_1 = require("../Label");
const styles_1 = require("./styles");
const assets_1 = require("../../assets");
const theme_1 = require("../../theme");
function Checkbox({ accessibilityRole = 'checkbox', iconStyle, disabled, label, labelPosition = 'end', labelStyle, onChange, selected, size, style, value, ...rest }) {
    const [checked, setChecked] = (0, react_1.useState)(selected ?? false);
    const theme = (0, theme_1.useTheme)();
    const themedStyle = (0, styles_1.getThemedStyles)(theme, labelPosition);
    const handleOnChange = (0, react_1.useCallback)(() => {
        onChange?.(value);
        setChecked(!checked);
    }, [onChange, value, checked]);
    const containerStyle = (0, react_1.useMemo)(() => ({
        ...themedStyle.container,
        ...(disabled && themedStyle.disabled),
    }), [disabled, themedStyle]);
    return (<react_native_1.Pressable {...rest} accessibilityRole={accessibilityRole} disabled={disabled} onPress={handleOnChange} style={[containerStyle, style]}>
      <Icon_1.Icon source={checked ? assets_1.icons.checkboxFilled : assets_1.icons.checkboxOutline} size={size} style={iconStyle}/>
      {label ? <Label_1.Label style={labelStyle}>{label}</Label_1.Label> : null}
    </react_native_1.Pressable>);
}
exports.default = Checkbox;
