"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getThemedStyles = void 0;
const react_native_1 = require("react-native");
const utils_1 = require("aws-amplify/utils");
const constants_1 = require("./constants");
const logger = new utils_1.ConsoleLogger('Icon-logger');
const getIconSize = (size) => {
    if (!size) {
        return constants_1.iconSizes.medium;
    }
    if (typeof size === 'number') {
        return size;
    }
    if (!constants_1.iconSizes[size]) {
        logger.warn(`"${size}" is not a valid icon size. Available values are: ${Object.keys(constants_1.iconSizes)}`);
        return constants_1.iconSizes.medium;
    }
    return constants_1.iconSizes[size];
};
const getThemedStyles = (theme, color, size) => {
    const { components } = theme;
    const iconSize = getIconSize(size);
    return react_native_1.StyleSheet.create({
        icon: {
            height: iconSize,
            resizeMode: 'contain',
            tintColor: color,
            width: iconSize,
            ...components?.icon,
        },
    });
};
exports.getThemedStyles = getThemedStyles;
