"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.INPUT_CONTAINER_TEST_ID = exports.TEXTFIELD_CONTAINER_TEST_ID = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_native_1 = require("react-native");
const Label_1 = require("../Label");
const theme_1 = require("../../theme");
const styles_1 = require("./styles");
exports.TEXTFIELD_CONTAINER_TEST_ID = 'amplify__text-field-container';
exports.INPUT_CONTAINER_TEST_ID = 'amplify__text-field__input-container';
function TextField({ accessibilityLabel, accessibilityRole, accessibilityState, accessible = true, autoCapitalize = 'none', disabled, endAccessory, error, errorMessage, errorMessageStyle, fieldStyle, label, labelStyle, style, ...rest }) {
    const theme = (0, theme_1.useTheme)();
    const themedStyle = (0, react_1.useMemo)(() => (0, styles_1.getThemedStyles)(theme), [theme]);
    const fieldContainerStyle = (0, react_1.useMemo)(() => ({
        ...themedStyle.fieldContainer,
        ...(disabled && themedStyle.disabled),
        ...(error && themedStyle.error),
    }), [disabled, error, themedStyle]);
    return (<react_native_1.View testID={exports.TEXTFIELD_CONTAINER_TEST_ID} style={[themedStyle.container, style]}>
      {label ? (<Label_1.Label accessibilityLabel={label} style={[themedStyle.label, labelStyle]}>
          {label}
        </Label_1.Label>) : null}
      <react_native_1.View accessible style={fieldContainerStyle} testID={exports.INPUT_CONTAINER_TEST_ID}>
        <react_native_1.TextInput {...rest} accessible={accessible} accessibilityLabel={label ? undefined : accessibilityLabel} accessibilityRole={accessibilityRole} accessibilityState={{ disabled, ...accessibilityState }} autoCapitalize={autoCapitalize} editable={!disabled} placeholderTextColor={theme.tokens.colors.font.tertiary} style={[themedStyle.field, fieldStyle]}/>
        {endAccessory ?? null}
      </react_native_1.View>
      {error && errorMessage ? (<Label_1.Label style={errorMessageStyle}>{errorMessage}</Label_1.Label>) : null}
    </react_native_1.View>);
}
exports.default = TextField;
